# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.14.3-v202504100944-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleConstantInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_index': 'int',
        'constant': 'object',
        'lookup_value': 'str'
    }

    attribute_map = {
        'column_index': 'columnIndex',
        'constant': 'constant',
        'lookup_value': 'lookupValue'
    }

    def __init__(self, column_index=None, constant=None, lookup_value=None):
        """
        ColumnRuleConstantInputV1 - a model defined in Swagger
        """

        self._column_index = None
        self._constant = None
        self._lookup_value = None

        if column_index is not None:
          self.column_index = column_index
        if constant is not None:
          self.constant = constant
        if lookup_value is not None:
          self.lookup_value = lookup_value

    @property
    def column_index(self):
        """
        Gets the column_index of this ColumnRuleConstantInputV1.
        The index of the column that contains the value to compare with the lookupValue. The column index is 1-based.

        :return: The column_index of this ColumnRuleConstantInputV1.
        :rtype: int
        """
        return self._column_index

    @column_index.setter
    def column_index(self, column_index):
        """
        Sets the column_index of this ColumnRuleConstantInputV1.
        The index of the column that contains the value to compare with the lookupValue. The column index is 1-based.

        :param column_index: The column_index of this ColumnRuleConstantInputV1.
        :type: int
        """

        self._column_index = column_index

    @property
    def constant(self):
        """
        Gets the constant of this ColumnRuleConstantInputV1.
        The constant to return within the table. This can be a string, numeric, boolean, item ID, or ISO 8601 timestamp. The type of the constant must match the column type.

        :return: The constant of this ColumnRuleConstantInputV1.
        :rtype: object
        """
        return self._constant

    @constant.setter
    def constant(self, constant):
        """
        Sets the constant of this ColumnRuleConstantInputV1.
        The constant to return within the table. This can be a string, numeric, boolean, item ID, or ISO 8601 timestamp. The type of the constant must match the column type.

        :param constant: The constant of this ColumnRuleConstantInputV1.
        :type: object
        """
        if constant is None:
            raise ValueError("Invalid value for `constant`, must not be `None`")

        self._constant = constant

    @property
    def lookup_value(self):
        """
        Gets the lookup_value of this ColumnRuleConstantInputV1.
        The value used for comparison with the value in columnIndex. The value in columnIndex must match this value exactly to return the constant.

        :return: The lookup_value of this ColumnRuleConstantInputV1.
        :rtype: str
        """
        return self._lookup_value

    @lookup_value.setter
    def lookup_value(self, lookup_value):
        """
        Sets the lookup_value of this ColumnRuleConstantInputV1.
        The value used for comparison with the value in columnIndex. The value in columnIndex must match this value exactly to return the constant.

        :param lookup_value: The lookup_value of this ColumnRuleConstantInputV1.
        :type: str
        """

        self._lookup_value = lookup_value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleConstantInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
