# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.14.3-v202504100944-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class RegexConfigFieldV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max_length': 'int',
        'min_length': 'int'
    }

    attribute_map = {
        'max_length': 'maxLength',
        'min_length': 'minLength'
    }

    def __init__(self, max_length=None, min_length=None):
        """
        RegexConfigFieldV1 - a model defined in Swagger
        """

        self._max_length = None
        self._min_length = None

        if max_length is not None:
          self.max_length = max_length
        if min_length is not None:
          self.min_length = min_length

    @property
    def max_length(self):
        """
        Gets the max_length of this RegexConfigFieldV1.
        The maximum allowed length of the regex string

        :return: The max_length of this RegexConfigFieldV1.
        :rtype: int
        """
        return self._max_length

    @max_length.setter
    def max_length(self, max_length):
        """
        Sets the max_length of this RegexConfigFieldV1.
        The maximum allowed length of the regex string

        :param max_length: The max_length of this RegexConfigFieldV1.
        :type: int
        """

        self._max_length = max_length

    @property
    def min_length(self):
        """
        Gets the min_length of this RegexConfigFieldV1.
        The minimum allowed length of the regex string

        :return: The min_length of this RegexConfigFieldV1.
        :rtype: int
        """
        return self._min_length

    @min_length.setter
    def min_length(self, min_length):
        """
        Sets the min_length of this RegexConfigFieldV1.
        The minimum allowed length of the regex string

        :param min_length: The min_length of this RegexConfigFieldV1.
        :type: int
        """

        self._min_length = min_length

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RegexConfigFieldV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
